@@ -1,7 +1,5 @@
-"""
-`refresh.py` is the main file to handle all the components of refreshing your model.
-"""
-from tabular_tracing import Refresh_Trace, Base_Trace
+"""`refresh.py` is the main file to handle all the components of refreshing your model."""
+from tabular_tracing import RefreshTrace, BaseTrace
 import logging
 from Microsoft.AnalysisServices.Tabular import (
     RefreshType,
@@ -18,19 +16,31 @@ from abc import ABC
 logger = logging.getLogger("PyTabular")
 
 
-class Refresh_Check(ABC):
-    """`Refresh_Check` is an assertion you run after your refreshes.
-    It will run the given `function` before and after refreshes,
-    then run the assertion of before and after. The default given in a refresh is to check row count.
-    It will check row count before, and row count after. Then fail if row count after is zero.
+class RefreshCheck(ABC):
+    """`RefreshCheck` is an test you run after your refreshes.
 
-    Args:
-        name (str): Name of Refresh_Check
-        function (function): Function to run before and after refresh.
-        assertion (function): Functino that takes a `pre` and `post` argument to output True or False.
+    It will run the given `function` before and after refreshes,
+    then run the assertion of before and after.
+    The default given in a refresh is to check row count.
+    It will check row count before, and row count after.
+    Then fail if row count after is zero.
     """
 
     def __init__(self, name: str, function, assertion=None) -> None:
+        """Sets the necessary components to perform a refresh check.
+
+        Args:
+            name (str): Name of refresh check.
+            function (Callable): Function to run on pre and post checks.
+                For example, a dax query. readme has examples of this.
+            assertion (Callable, optional): A function that can be run.
+            Supply the assertion function with 2 arguments. The first one
+            for your 'pre' results from the `function` argument. The second
+            for your `post` results from the`function` argument.
+            Return `True` or `False` depending on the comparison of the two arguments
+            to determine a pass or fail status of your refresh.
+            Defaults to None.
+        """
         super().__init__()
         self._name = name
         self._function = function
@@ -39,14 +49,12 @@ class Refresh_Check(ABC):
         self._post = None
 
     def __repr__(self) -> str:
-        """
-        `__repre__` that returns details on `Refresh_Check`.
-        """
+        """`__repre__` that returns details on `RefreshCheck`."""
         return f"{self.name} - {self.pre} - {self.post} - {str(self.function)}"
 
     @property
     def name(self):
-        "Get your custom name of refresh check."
+        """Get your custom name of refresh check."""
         return self._name
 
     @name.setter
@@ -59,7 +67,7 @@ class Refresh_Check(ABC):
 
     @property
     def function(self):
-        "Get the function that is used to run a pre and post check."
+        """Get the function that is used to run a pre and post check."""
         return self._function
 
     @function.setter
@@ -72,7 +80,7 @@ class Refresh_Check(ABC):
 
     @property
     def pre(self):
-        "Get the pre value that is the result from the pre refresh check."
+        """Get the pre value that is the result from the pre refresh check."""
         return self._pre
 
     @pre.setter
@@ -85,7 +93,7 @@ class Refresh_Check(ABC):
 
     @property
     def post(self):
-        "Get the post value that is the result from the post refresh check."
+        """Get the post value that is the result from the post refresh check."""
         return self._post
 
     @post.setter
@@ -98,7 +106,7 @@ class Refresh_Check(ABC):
 
     @property
     def assertion(self):
-        "Get the assertion that is the result from the post refresh check."
+        """Get the assertion that is the result from the post refresh check."""
         return self._assertion
 
     @assertion.setter
@@ -111,6 +119,7 @@ class Refresh_Check(ABC):
 
     def _check(self, stage: str):
         """Runs the given function and stores results.
+
         Stored in either `self.pre` or `self.post` depending on `stage`.
 
         Args:
@@ -128,26 +137,27 @@ class Refresh_Check(ABC):
         logger.info(f"{stage}-Check results for {self.name} - {results}")
         return results
 
-    def Pre_Check(self):
-        """Runs `self._check("Pre")`"""
+    def pre_check(self):
+        """Runs `self._check("Pre")`."""
         self._check("Pre")
         pass
 
-    def Post_Check(self):
-        """Runs `self._check("Post")` then `self.Assertion()`"""
+    def post_check(self):
+        """Runs `self._check("Post")` then `self.assertion_run()`."""
         self._check("Post")
-        self.Assertion()
+        self.assertion_run()
         pass
 
-    def Assertion(self):
+    def assertion_run(self):
         """Runs the given self.assertion function with `self.pre` and `self.post`.
-        So, `self.assertion(self.pre, self.post)`.
+
+        So, `self.assertion_run(self.pre, self.post)`.
         """
         if self.assertion is None:
             logger.debug("Skipping assertion none given")
         else:
             test = self.assertion(self.pre, self.post)
-            assert_str = f"Test {self.name} - {test} - Pre Results - {self.pre} | Post Results {self.post}"
+            assert_str = f"Test {self.name} - {test} - Pre Results - {self.pre} | Post Results {self.post}"  # noqa: E501
             if test:
                 logger.info(assert_str)
             else:
@@ -157,60 +167,79 @@ class Refresh_Check(ABC):
             ), f"Test failed! Pre Results - {self.pre} | Post Results {self.post}"
 
 
-class Refresh_Check_Collection:
-    """Groups together your `Refresh_Checks` to handle multiple types of checks in a single refresh."""
+class RefreshCheckCollection:
+    """Groups together your `RefreshChecks`.
 
-    def __init__(self, refresh_checks: Refresh_Check = []) -> None:
-        self._refresh_checks = refresh_checks
+    Used to handle multiple types of checks in a single refresh.
+    """
+
+    def __init__(self, refresh_checks: RefreshCheck = []) -> None:
+        """Init to supply RefreshChecks.
+
+        Args:
+            refresh_checks (RefreshCheck, optional): Defaults to [].
+        """
+        self._refreshchecks = refresh_checks
         pass
 
     def __iter__(self):
-        """Basic iteration through the different `Refresh_Check`(s)."""
-        for refresh_check in self._refresh_checks:
+        """Basic iteration through the different `RefreshCheck`(s)."""
+        for refresh_check in self._refreshchecks:
             yield refresh_check
 
-    def add_refresh_check(self, refresh_check: Refresh_Check):
-        """Add a Refresh_Check
+    def add_refresh_check(self, refresh_check: RefreshCheck):
+        """Add a RefreshCheck.
+
+        Supply the `RefreshCheck` to add.
 
         Args:
-            refresh_check (Refresh_Check): `Refresh_Check` class.
+            refresh_check (RefreshCheck): `RefreshCheck` class.
         """
-        self._refresh_checks.append(refresh_check)
+        self._refreshchecks.append(refresh_check)
 
-    def remove_refresh_check(self, refresh_check: Refresh_Check):
-        """Remove a Refresh_Check
+    def remove_refresh_check(self, refresh_check: RefreshCheck):
+        """Remove a RefreshCheck.
+
+        Supply the `RefreshCheck` to remove.
 
         Args:
-            refresh_check (Refresh_Check): `Refresh_Check` class.
+            refresh_check (RefreshCheck): `RefreshCheck` class.
         """
-        self._refresh_checks.remove(refresh_check)
+        self._refreshchecks.remove(refresh_check)
 
     def clear_refresh_checks(self):
         """Clear Refresh Checks."""
-        self._refresh_checks.clear()
+        self._refreshchecks.clear()
 
 
 class PyRefresh:
-    """PyRefresh Class to handle refreshes of model.
-
-    Args:
-        model (Tabular): Main Tabular Class
-        object (Union[str, PyTable, PyPartition, Dict[str, Any]]): Designed to handle a few different ways of selecting a refresh. Can be a string of 'Table Name' or dict of {'Table Name': 'Partition Name'} or even some combination with the actual PyTable and PyPartition classes.
-        trace (Base_Trace, optional): Set to `None` if no Tracing is desired, otherwise you can use default trace or create your own. Defaults to Refresh_Trace.
-        refresh_checks (Refresh_Check_Collection, optional): Add your `Refresh_Check`'s into a `Refresh_Check_Collection`. Defaults to Refresh_Check_Collection().
-        default_row_count_check (bool, optional): Quick built in check will fail the refresh if post check row count is zero. Defaults to True.
-        refresh_type (RefreshType, optional): Input RefreshType desired. Defaults to RefreshType.Full.
-    """
+    """PyRefresh Class to handle refreshes of model."""
 
     def __init__(
         self,
         model,
         object: Union[str, PyTable, PyPartition, Dict[str, Any]],
-        trace: Base_Trace = Refresh_Trace,
-        refresh_checks: Refresh_Check_Collection = Refresh_Check_Collection(),
+        trace: BaseTrace = RefreshTrace,
+        refresh_checks: RefreshCheckCollection = RefreshCheckCollection(),
         default_row_count_check: bool = True,
         refresh_type: RefreshType = RefreshType.Full,
     ) -> None:
+        """Init when a refresh is requested.
+
+        Runs through requested tables and partitions
+        to make sure they are in model.
+        Then will run pre checks on the requested objects.
+
+        Args:
+            model (Tabular): Tabular model.
+            object (Union[str, PyTable, PyPartition, Dict[str, Any]]): The objects
+                that you are wanting to refresh. Can be a `PyTable`, `PyPartition`,
+                `TABLE_NAME` string, or a dict with `{TABLE_REFERENCE:PARTITION_REFERENCE}`
+            trace (BaseTrace, optional): Defaults to RefreshTrace.
+            refresh_checks (RefreshCheckCollection, optional): Defaults to RefreshCheckCollection().
+            default_row_count_check (bool, optional): Defaults to True.
+            refresh_type (RefreshType, optional): Defaults to RefreshType.Full.
+        """
         self.model = model
         self.object = object
         self.trace = trace
@@ -224,8 +253,9 @@ class PyRefresh:
         pass
 
     def _pre_checks(self):
-        """Checks if any `Base_Trace` classes are needed from `Tabular_Tracing.py`.
-        Then checks if any `Refresh_Checks` are needed, along with the default `Row_Count` check.
+        """Checks if any `BaseTrace` classes are needed from `tabular_tracing.py`.
+
+        Then checks if any `RefreshChecks` are needed, along with the default `row_count` check.
         """
         logger.debug("Running Pre-checks")
         if self.trace is not None:
@@ -247,27 +277,29 @@ class PyRefresh:
                 return post > 0
 
             for table in set(tables):
-                check = Refresh_Check(
-                    f"{table.Name} Row Count", table.Row_Count, row_count_assertion
+                check = RefreshCheck(
+                    f"{table.Name} Row Count", table.row_count, row_count_assertion
                 )
                 self._checks.add_refresh_check(check)
         for check in self._checks:
-            check.Pre_Check()
+            check.pre_check()
         pass
 
     def _post_checks(self):
         """If traces are running it Stops and Drops it.
-        Runs through any `Post_Checks()` in `Refresh_Checks`.
+
+        Runs through any `post_checks()` in `RefreshChecks`.
         """
         if self.trace is not None:
-            self.trace.Stop()
-            self.trace.Drop()
+            self.trace.stop()
+            self.trace.drop()
         for check in self._checks:
-            check.Post_Check()
-            self._checks.remove_refresh_check(check)
+            check.post_check()
+            # self._checks.remove_refresh_check(check)
+        self._checks.clear_refresh_checks()
         pass
 
-    def _get_trace(self) -> Base_Trace:
+    def _get_trace(self) -> BaseTrace:
         """Creates Trace and creates it in model."""
         return self.trace(self.model)
 
@@ -309,8 +341,8 @@ class PyRefresh:
             table_object = self._find_table(table) if isinstance(table, str) else table
 
             def handle_partitions(object):
-                """
-                Figures out if partition argument given is a str or an actual `PyPartition`.
+                """Figures out if partition argument given is a str or an actual `PyPartition`.
+
                 Then will run `self._refresh_partition()` appropriately.
                 """
                 if isinstance(object, str):
@@ -323,7 +355,10 @@ class PyRefresh:
             handle_partitions(partition_dict[table])
 
     def _request_refresh(self, object):
-        """Base method to parse through argument and figure out what needs to be refreshed. Someone please make this better..."""
+        """Base method to parse through argument and figure out what needs to be refreshed.
+
+        Someone please make this better...
+        """
         logger.debug(f"Requesting Refresh for {object}")
         if isinstance(object, str):
             self._refresh_table(self._find_table(object))
@@ -338,48 +373,53 @@ class PyRefresh:
         else:
             [self._request_refresh(obj) for obj in object]
 
-    def _refresh_report(self, Property_Changes) -> pd.DataFrame:
+    def _refresh_report(self, property_changes) -> pd.DataFrame:
         """Builds a DataFrame that displays details on the refresh.
 
         Args:
-            Property_Changes: Which is returned from `model.SaveChanges()`
+            Property_Changes: Which is returned from `model.save_changes()`
 
         Returns:
             pd.DataFrame: DataFrame of refresh details.
         """
         logger.debug("Running Refresh Report...")
         refresh_data = []
-        for property_change in Property_Changes:
+        for property_change in property_changes:
             if (
-                isinstance(property_change.Object, Partition)
-                and property_change.Property_Name == "RefreshedTime"
+                isinstance(property_change.object, Partition)
+                and property_change.property_name == "RefreshedTime"
             ):
                 table, partition, refreshed_time = (
-                    property_change.Object.Table.Name,
-                    property_change.Object.Name,
-                    ticks_to_datetime(property_change.New_Value.Ticks),
+                    property_change.object.Table.Name,
+                    property_change.object.Name,
+                    ticks_to_datetime(property_change.new_value.Ticks),
                 )
                 logger.info(
-                    f'{table} - {partition} Refreshed! - {refreshed_time.strftime("%m/%d/%Y, %H:%M:%S")}'
+                    f'{table} - {partition} Refreshed! - {refreshed_time.strftime("%m/%d/%Y, %H:%M:%S")}'  # noqa: E501
                 )
                 refresh_data += [[table, partition, refreshed_time]]
         return pd.DataFrame(
             refresh_data, columns=["Table", "Partition", "Refreshed Time"]
         )
 
-    def Run(self) -> pd.DataFrame:
-        """Brings it all together. When ready, executes all the pre checks.
-        Then refreshes. Then runs all the post checks.
+    def run(self) -> pd.DataFrame:
+        """When ready, execute to start the refresh process.
+
+        First checks if connected and reconnects if needed.
+        Then starts the trace if needed.
+        Next will execute `save_changes()`
+        and run the post checks after that.
+        Last will return a `pd.DataFrame` of refresh results.
         """
         if self.model.Server.Connected is False:
             logger.info(f"{self.Server.Name} - Reconnecting...")
-            self.model.Server.Reconnect()
+            self.model.reconnect()
 
         if self.trace is not None:
-            self.trace.Start()
+            self.trace.start()
 
-        save_changes = self.model.SaveChanges()
+        save_changes = self.model.save_changes()
 
         self._post_checks()
 
-        return self._refresh_report(save_changes.Property_Changes)
+        return self._refresh_report(save_changes.property_changes)
